<?php

namespace Drupal\feeds_filemaker\Feeds\Fetcher\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\feeds\Feeds\Fetcher\Form\HttpFetcherForm;

class FileMakerApiFetcherForm extends HttpFetcherForm {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    $form['batch_size'] = [
      '#type' => 'number',
      '#title' => $this->t('Batch Size'),
      '#description' => $this->t('The number of items to fetch in each API request.'),
      '#default_value' => $this->plugin->getConfiguration('batch_size'),
      '#min' => 1,
      '#max' => 1000,
      '#required' => TRUE,
    ];

    $form['max_batches'] = [
      '#type' => 'number',
      '#title' => $this->t('Maximum Batches per Run'),
      '#description' => $this->t('The maximum number of batches to process in a single import run. Use 0 for no limit.'),
      '#default_value' => $this->plugin->getConfiguration('max_batches'),
      '#min' => 0,
      '#required' => TRUE,
    ];

    $form['throttle_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Throttling'),
      '#description' => $this->t('If checked, the import will pause between batches to avoid overwhelming the API.'),
      '#default_value' => $this->plugin->getConfiguration('throttle_enabled'),
    ];

    $form['throttle_delay'] = [
      '#type' => 'number',
      '#title' => $this->t('Throttle Delay'),
      '#description' => $this->t('The number of seconds to wait between batches when throttling is enabled.'),
      '#default_value' => $this->plugin->getConfiguration('throttle_delay'),
      '#min' => 1,
      '#states' => [
        'visible' => [
          ':input[name="fetcher_configuration[throttle_enabled]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::validateConfigurationForm($form, $form_state);

    $batch_size = $form_state->getValue('batch_size');
    if ($batch_size < 1 || $batch_size > 1000) {
      $form_state->setErrorByName('batch_size', $this->t('Batch size must be between 1 and 1000.'));
    }

    $max_batches = $form_state->getValue('max_batches');
    if ($max_batches < 0) {
      $form_state->setErrorByName('max_batches', $this->t('Maximum batches must be 0 or a positive integer.'));
    }

    if ($form_state->getValue('throttle_enabled')) {
      $throttle_delay = $form_state->getValue('throttle_delay');
      if ($throttle_delay < 1) {
        $form_state->setErrorByName('throttle_delay', $this->t('Throttle delay must be at least 1 second.'));
      }
    }
  }
}
